@@ -14,7 +14,8 @@ import (
 
 func main() {
 	config.ProcessSubprocessArgs(config.DefaultLoggingConfig)
-	util.SetLogging("apivip_check", config.SubprocessConfig.TextLogging, config.SubprocessConfig.JournalLogging)
+	config.ProcessDryRunArgs()
+	util.SetLogging("apivip_check", config.SubprocessConfig.TextLogging, config.SubprocessConfig.JournalLogging, config.GlobalDryRunConfig.ForcedHostID)
 	if flag.NArg() != 1 {
 		log.Warnf("Expecting exactly single argument to apivip_check. Received %d", len(os.Args)-1)
 		os.Exit(-1)
