@@ -13,7 +13,8 @@ import (
 
 func main() {
 	config.ProcessSubprocessArgs(config.DefaultLoggingConfig)
-	util.SetLogging("dhcp_lease_allocate", config.SubprocessConfig.TextLogging, config.SubprocessConfig.JournalLogging)
+	config.ProcessDryRunArgs()
+	util.SetLogging("dhcp_lease_allocate", config.SubprocessConfig.TextLogging, config.SubprocessConfig.JournalLogging, config.GlobalDryRunConfig.ForcedHostID)
 	if flag.NArg() != 1 {
 		log.Warnf("Expecting exactly single argument to dhcp_lease_allocate. Received %d", len(os.Args)-1)
 		os.Exit(-1)
